﻿using System.Collections;
using System.Collections.ObjectModel;
using System.Windows.Data;
using WpfTreeView.Model;

namespace WpfTreeView.ViewModel
{
    public class ArticleCategoryViewModel : ViewModelBase
    {
        private readonly ArticleCategory _articleCategory;

        public ArticleCategoryViewModel(ArticleCategory articleCategory)
        {
            _articleCategory = articleCategory;
            LoadChildren();
        }

        public int Id => _articleCategory.Id;
        public string CategoryName => _articleCategory.CategoryName;

        private ObservableCollection<ArticleCategoryViewModel> _subCategories;
        public ObservableCollection<ArticleCategoryViewModel> SubCategories { get => _subCategories; set => SetValue(ref _subCategories, value); }

        private ObservableCollection<ArticleViewModel> _articles;
        public ObservableCollection<ArticleViewModel> Articles { get => _articles; set => SetValue(ref _articles, value); }

        public IList Children => new CompositeCollection{
            new CollectionContainer()
        {
            Collection = SubCategories},
            new CollectionContainer() { Collection = Articles} };

        void LoadChildren()
        {
            
            var subs = _articleCategory.SubCategories;
            if(subs != null)
            {
                SubCategories = new ObservableCollection<ArticleCategoryViewModel>();
                foreach (var sub in subs)
                {
                    SubCategories.Add(new ArticleCategoryViewModel(sub));
                }
            }       

            var articles = _articleCategory.Articles;
            if(articles != null)
            {
                Articles = new ObservableCollection<ArticleViewModel>();
                foreach (var article in articles)
                {
                    Articles.Add(new ArticleViewModel(article));
                }
            }
           
        }
    }
}
